# Generated by Django 4.0.5 on 2022-10-28 13:46

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import imagekit.models.fields
import openbook_posts.helpers
import openbook_posts.validators
from comments.validators import comment_text_hashtags_validator
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("openbook_communities", "0001_initial"),
        ("contenttypes", "0002_remove_content_type_name"),
        ("openbook_common", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Post",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("uuid", models.UUIDField(db_index=True, default=uuid.uuid4, editable=False, unique=True)),
                (
                    "text",
                    models.TextField(
                        max_length=5000,
                        null=True,
                        validators=[openbook_posts.validators.post_text_hashtags_validator],
                        verbose_name="text",
                    ),
                ),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                ("modified", models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                (
                    "comments_enabled",
                    models.BooleanField(default=True, editable=False, verbose_name="comments enabled"),
                ),
                (
                    "public_reactions",
                    models.BooleanField(default=True, editable=False, verbose_name="public reactions"),
                ),
                ("is_edited", models.BooleanField(default=False)),
                ("is_closed", models.BooleanField(default=False)),
                ("is_deleted", models.BooleanField(default=False)),
                (
                    "status",
                    models.CharField(
                        choices=[("D", "Draft"), ("PG", "Processing"), ("P", "Published")], default="D", max_length=2
                    ),
                ),
                ("media_height", models.PositiveSmallIntegerField(null=True, verbose_name="media height")),
                ("media_width", models.PositiveSmallIntegerField(null=True, verbose_name="media width")),
                (
                    "media_thumbnail",
                    imagekit.models.fields.ProcessedImageField(
                        max_length=500,
                        null=True,
                        upload_to=openbook_posts.helpers.upload_to_post_directory,
                        verbose_name="thumbnail",
                    ),
                ),
                (
                    "community",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="posts",
                        to="openbook_communities.community",
                    ),
                ),
                (
                    "creator",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="posts", to=settings.AUTH_USER_MODEL
                    ),
                ),
                (
                    "language",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="posts",
                        to="openbook_common.language",
                    ),
                ),
            ],
            options={
                "index_together": {("creator", "community")},
            },
        ),
        migrations.CreateModel(
            name="PostComment",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                ("modified", models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                (
                    "text",
                    models.TextField(
                        max_length=1500,
                        validators=[comment_text_hashtags_validator],
                        verbose_name="text",
                    ),
                ),
                ("is_edited", models.BooleanField(default=False)),
                ("is_deleted", models.BooleanField(default=False)),
                (
                    "commenter",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="posts_comments",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "language",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="post_comments",
                        to="openbook_common.language",
                    ),
                ),
                (
                    "parent_comment",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="replies",
                        to="openbook_posts.postcomment",
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="comments", to="openbook_posts.post"
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="TrendingPost",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                (
                    "post",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="trending_post",
                        to="openbook_posts.post",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="TopPost",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                (
                    "post",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE, related_name="top_post", to="openbook_posts.post"
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="PostMedia",
            fields=[
                ("order", models.PositiveIntegerField(db_index=True, editable=False, verbose_name="order")),
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("type", models.CharField(choices=[("V", "Video"), ("I", "Image")], max_length=5)),
                ("object_id", models.CharField(max_length=36)),
                (
                    "content_type",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="contenttypes.contenttype"),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="media", to="openbook_posts.post"
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="PostLink",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("uuid", models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ("link", models.TextField(max_length=5000)),
                ("has_preview", models.BooleanField(default=False)),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="links", to="openbook_posts.post"
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="PostImage",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                (
                    "image",
                    imagekit.models.fields.ProcessedImageField(
                        height_field="height",
                        max_length=500,
                        null=True,
                        upload_to=openbook_posts.helpers.upload_to_post_image_directory,
                        verbose_name="image",
                        width_field="width",
                    ),
                ),
                ("width", models.PositiveIntegerField(editable=False)),
                ("height", models.PositiveIntegerField(editable=False)),
                ("hash", models.CharField(max_length=64, null=True, verbose_name="hash")),
                (
                    "thumbnail",
                    imagekit.models.fields.ProcessedImageField(
                        max_length=500,
                        null=True,
                        upload_to=openbook_posts.helpers.upload_to_post_image_directory,
                        verbose_name="thumbnail",
                    ),
                ),
                (
                    "post",
                    models.OneToOneField(
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="image",
                        to="openbook_posts.post",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="TopPostCommunityExclusion",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                (
                    "community",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="top_posts_community_exclusions",
                        to="openbook_communities.community",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="top_posts_community_exclusions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("user", "community")},
            },
        ),
        migrations.CreateModel(
            name="ProfilePostsCommunityExclusion",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(db_index=True, editable=False)),
                (
                    "community",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="profile_posts_community_exclusions",
                        to="openbook_communities.community",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="profile_posts_community_exclusions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("user", "community")},
            },
        ),
        migrations.CreateModel(
            name="PostUserMention",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="user_mentions",
                        to="openbook_posts.post",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_mentions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("user", "post")},
            },
        ),
        migrations.CreateModel(
            name="PostReaction",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(editable=False)),
                (
                    "emoji",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_reactions",
                        to="openbook_common.emoji",
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="reactions", to="openbook_posts.post"
                    ),
                ),
                (
                    "reactor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_reactions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("reactor", "post")},
            },
        ),
        migrations.CreateModel(
            name="PostMute",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                (
                    "muter",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_mutes",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="mutes", to="openbook_posts.post"
                    ),
                ),
            ],
            options={
                "unique_together": {("post", "muter")},
            },
        ),
        migrations.CreateModel(
            name="PostCommentUserMention",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                (
                    "post_comment",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="user_mentions",
                        to="openbook_posts.postcomment",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_comment_mentions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("user", "post_comment")},
            },
        ),
        migrations.CreateModel(
            name="PostCommentReaction",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(editable=False)),
                (
                    "emoji",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_comment_reactions",
                        to="openbook_common.emoji",
                    ),
                ),
                (
                    "post_comment",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="reactions",
                        to="openbook_posts.postcomment",
                    ),
                ),
                (
                    "reactor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_comment_reactions",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("reactor", "post_comment")},
            },
        ),
        migrations.CreateModel(
            name="PostCommentMute",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                (
                    "muter",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_comment_mutes",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "post_comment",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="mutes",
                        to="openbook_posts.postcomment",
                    ),
                ),
            ],
            options={
                "unique_together": {("post_comment", "muter")},
            },
        ),
    ]
